@@ -15,6 +15,8 @@ limitations under the License.
 
 """
 
+import asyncio
+
 import aioredis
 from aioredis import ReplyError
 
@@ -103,16 +105,24 @@ class AIORedisBackend(RedisBackend):
     def __init__(self, config=None):
         if not (config is None or isinstance(config, dict)):
             raise ValueError("`config` must be an instance of dict or None")
-        # redis配置
-        self.connection_timeout = config.get('CACHE_REDIS_CONNECTION_TIMEOUT', 3)
-        # 连接池
-        self.use_pool = config.get('CACHE_REDIS_USE_POOL', True)
-        self.pool_minsize = config.get('CACHE_REDIS_POOL_MINSIZE', 1)
-        self.pool_maxsize = config.get('CACHE_REDIS_POOL_MAXSIZE', 50)
-        # encoding
-        self.encoding = config.get('CACHE_REDIS_ENCODING', 'utf-8')
 
-        super().__init__(config)
+        if config is not None:
+            # redis配置
+            self.connection_timeout = config.get('CACHE_REDIS_CONNECTION_TIMEOUT', 3)
+            # 连接池
+            self.use_pool = config.get('CACHE_REDIS_USE_POOL', True)
+            self.pool_minsize = config.get('CACHE_REDIS_POOL_MINSIZE', 3)
+            self.pool_maxsize = config.get('CACHE_REDIS_POOL_MAXSIZE', 10)
+            # encoding
+            self.encoding = config.get('CACHE_REDIS_ENCODING', 'utf-8')
+        else:
+            self.connection_timeout = 3
+            self.use_pool = True
+            self.pool_minsize = 3
+            self.pool_maxsize = 10
+            self.encoding = 'utf-8'
+
+        super().__init__(config=config)
 
     def create_cache_context(self):
         """
@@ -134,6 +144,25 @@ class AIORedisBackend(RedisBackend):
                 encoding=self.encoding,
             )
 
+    def get_cache_context(self):
+        """
+        Implement function from CacheBackendContext interface
+        @See CacheBackendContext.get_cache_context
+        """
+        return self._redis_cache_context
+
+    async def destroy_cache_context(self):
+        """
+        Implement function from CacheBackendContext interface
+        @See CacheBackendContext.destroy_cache_context
+        """
+        if not self._redis_cache_context:
+            return
+        await self._redis_cache_context.destroy()
+        self._redis_cache_context = None
+        # just wait
+        return await asyncio.sleep(0.01)
+
     def get_async_context(self):
         """
         Implement function from RedisBackend interface
@@ -282,21 +311,53 @@ class AIORedisBackend(RedisBackend):
         else:
             raise TypeError("Execute command can not empty")
         try:
-            async with self.get_async_context() as conn:
-                if str.lower(cmd) == "get":
-                    result = await self.get(*args_ex_cmd, **kwargs)
-                elif str.lower(cmd) == "mget":
-                    result = await self.get_many(*args_ex_cmd, **kwargs)
-                elif str.lower(cmd) == "set":
-                    result = await self.set(*args_ex_cmd, **kwargs)
-                elif str.lower(cmd) == "mset":
-                    result = await self.set_many(*args_ex_cmd, **kwargs)
-                else:
+            cmd = str.lower(cmd)
+            if cmd == "get":
+                result = await self.get(*args_ex_cmd, **kwargs)
+            elif cmd == "mget":
+                result = await self.get_many(*args_ex_cmd, **kwargs)
+            elif cmd == "set":
+                result = await self.set(*args_ex_cmd, **kwargs)
+            elif cmd == "mset":
+                result = await self.set_many(*args_ex_cmd, **kwargs)
+            elif cmd == "del":
+                result = await self.delete(*args_ex_cmd, **kwargs)
+            elif cmd in ["ping", "quit", "bgsave", "dbsize", "time",
+                         "info", "lastsave", "flushdb", "sync", "bgrewriteaof"]:
+                # simple commands
+                async with self.get_async_context() as conn:
                     result = await conn.execute(*args, **kwargs)
+            else:
+                result = await self.execute_key(*args, **kwargs)
+            return result
         except ReplyError as ex:
             # ReplyError
             raise TypeError("Execute command type error,detail=%s" % str(ex))
-        return result
+
+    async def execute_key(self, *args, **kwargs):
+        cmd = args[0]
+        args_except_cmd = args[1:]
+        args_to_execute = [cmd]
+        if len(args_except_cmd) > 0:
+            # 默认第一个参数为key
+            key = self.make_key(args_except_cmd[0])
+            args_to_execute.append(key)
+            args_to_execute.extend(args_except_cmd[1:])
+        else:
+            raise TypeError("Too many or no key to execute, command = %s param =%s kwargs= %s"
+                            % (str(cmd), str(*args_except_cmd), str({**kwargs})))
+
+        async with self.get_async_context() as conn:
+            cmd = str.lower(cmd)
+            if cmd == "dump":
+                result = await conn.dump(key)
+            elif cmd == "incr":
+                result = await conn.incr(key)
+            elif cmd == "decr":
+                result = await conn.decr(key)
+            else:
+                result = await conn.execute(*tuple(args_to_execute), **kwargs)
+            return result
 
     async def clear(self):
         """
